=============================================================
 tooz -- Distributed System Helper Library
=============================================================

The Tooz project aims at centralizing the most common distributed primitives
like group membership protocol, lock service and leader election by providing
a coordination API helping developers to build distributed applications.
Contents:

.. toctree::
   :glob:

   install
   drivers
   tutorial/index

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
